# Table of Contents

- [presentations](<./presentations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Presentations](<./Presentations.md>)
  - [Overview](<./Presentations/Overview.md>)
  - [Creating a Presentation](<./Presentations/Creating-a-Presentation.md>)
  - [Adding Notes to Slides](<./Presentations/Adding-Notes-to-Slides.md>)
  - [Adding, Rearranging, and Deleting Slides](<./Presentations/Adding-Rearranging-and-Deleting-Slides.md>)
  - [Changing Permissions for Reports and Diagrams](<./Presentations/Changing-Permissions-for-Reports-and-Diagrams.md>)
  - [Previewing and Starting a Presentation](<./Presentations/Previewing-and-Starting-a-Presentation.md>)
  - [Presentation Details](<./Presentations/Presentation-Details.md>)
  - [Presentation Permissions](<./Presentations/Presentation-Permissions.md>)
  - [Permission Types](<./Presentations/Permission-Types.md>)
  - [Changing Presentation Permissions and Ownership](<./Presentations/Changing-Presentation-Permissions-and-Ownership.md>)
  - [Sharing a Presentation](<./Presentations/Sharing-a-Presentation.md>)
  - [Managing Presentations in Bulk](<./Presentations/Managing-Presentations-in-Bulk.md>)
  - [Was this page helpful?](<./Presentations/Was-this-page-helpful.md>)
